document.addEventListener("DOMContentLoaded", () => {
  const brandInput = document.getElementById("brandInput");
  const searchButton = document.getElementById("searchButton");
  const resultContainer = document.getElementById("resultContainer");

  const checkBrandAvailability = async (brandName) => {
    try {
      // Fetch data from DuckDuckGo API
      const response = await fetch(
        `https://api.duckduckgo.com/?q=${encodeURIComponent(brandName)}&format=json&no_html=1`,
      );
      const data = await response.json();

      // If the API returns an abstract, assume the brand is in use
      const isAvailable = !data.AbstractText;
      return isAvailable;
    } catch (error) {
      console.error("Error fetching data:", error);
      throw new Error("An error occurred while checking availability.");
    }
  };

  const displayResult = (isAvailable) => {
    resultContainer.innerHTML = "";
    const resultMessage = document.createElement("p");
    resultMessage.textContent = isAvailable
      ? "✅ Brand name is available!"
      : "❌ Brand name is already in use";
    resultMessage.className = isAvailable ? "success" : "error";
    resultContainer.appendChild(resultMessage);
  };

  searchButton.addEventListener("click", async () => {
    const brandName = brandInput.value.trim();
    if (brandName) {
      resultContainer.textContent = "Checking availability...";
      try {
        const isAvailable = await checkBrandAvailability(brandName);
        displayResult(isAvailable);
      } catch (error) {
        resultContainer.textContent = error.message;
        resultContainer.className = "error";
      }
    } else {
      resultContainer.textContent = "Please enter a brand name";
      resultContainer.className = "error";
    }
  });

  brandInput.addEventListener("keypress", (e) => {
    if (e.key === "Enter") {
      searchButton.click();
    }
  });
});
